@@ -1,16 +1,16 @@
 from .convert.xlsx import convert_to_xlsx, write_workbook
 from .convert.csv import convert_to_csv
 from .convert.json import convert_to_json
-from .services.services import Services
-from .commands.compare import ModelComparer
+from .compare import ModelComparer
+from .evaluation.evaluation import Evaluation
 
 
-__version__ = "0.3.28"
+__version__ = "0.5.0"
 __all__ = [
     "convert_to_csv",
     "convert_to_xlsx",
     "convert_to_json",
-    "Services",
     "write_workbook",
     "ModelComparer",
+    "Evaluation"
 ]
