@@ -1,44 +1,52 @@
-from typing import List
+from pathlib import Path
+from typing import Dict, List
 
 import xlsxwriter
 import pandas as pd
 import numpy as np
 
-from .commons import run_requests, structure_sheets, structure_sheet
-from ..commons.consts import RED_TO_GREEN_GRADIENT
-from ..services.services import Services
+from hycli.commons.jobs import run_requests
+from hycli.commons.structure import structure_sheets, structure_sheet
+from hycli.commons.consts import RED_TO_GREEN_GRADIENT
 
 
 def convert_to_xlsx(
-    input_path: str,
-    services: Services,
+    files: Dict[Path, str],
+    url: str,
+    headers: Dict,
+    params: Dict,
+    token: str,
     workers: int = 1,
-    output_path: str = None,
-    normalize: bool = None,
+    normalize: bool = False,
+    output_path: Path = Path("hycli.xlsx"),
 ):
-    """Sends requests to defined Hypatos services for every invoice found in given
+    """Converts all documents (\*.pdf, \*.png etc) and JSON OCR files found in the directory and saves them in XLSX structure.
+    Sends requests to defined Hypatos service for every document found in given
     directory. Merges results off all services into one Excel file and writes to
     project directory. Every key, value pair from Invoice Extractor will flattened
     into the following tuple:
 
         key = (value, probability)
 
-    Arguments:
-        path {str} -- Path to the directory containing invoices, uses rglob.
-        extractor_endpoint {str} -- Url of Hypatos extractor service.
+    Args:
+        files (dict): Dictionary of processed files containing PosixPath as a key and MIME type as a value
+        url (str): URL endpoint of exposed Hypatos Invoice Extractor
+        headers (dict): Optional. Extractor endpoint header(s) can be multiple.
+        params (dict): Optional. Extractor endpoint param(s) can be multiple.
+        token (str): API token. (default: {None})
+        workers (int): Amount of multithread. (default: {1})
+        normalize (bool): Normalize probability of every individual column from [min, max] to [0,1]. (default: {False})
+        output_path (PosixPath): output directory for CSV file
 
-    Keyword Arguments:
-        token {str} -- API token. (default: {None})
-        workers {int} -- Amount of multithread. (default: {1})
-    """
+    """  # NOQA
     # Get requests result
-    response = run_requests(workers, input_path, services)
+    extracted_files = run_requests(files, url, workers, headers, params, token)
 
     # Structure response into sheets (dict) containing records [{...}, {...}]
-    sheets = structure_sheets(response)
+    sheets = structure_sheets(extracted_files)
 
     # Normalize probability
-    if normalize and (services.headers.get("probabilities") == "true"):
+    if normalize and (headers.get("probabilities") == "true"):
         for sheet in sheets.copy():
             sheets[sheet] = normalize_probability(sheets[sheet])
 
@@ -47,6 +55,13 @@ def convert_to_xlsx(
 
 
 def write_workbook(output_path: str, sheets: List[dict]):
+    """Writes a list of sheets into a Excel workbook, every sheet is a dict with a records structure.
+
+    Args:
+        output_path (PosixPath): output path of written workbook.
+        sheets (dict): dictionary containing key-value pairs of sheet names and flattened extraction.
+
+    """
     # Init workbook/sheets
     workbook = xlsxwriter.Workbook(output_path)
 
@@ -120,7 +135,7 @@ def get_col_widths(invoices, max_col_width=70):
 
 
 def normalize_probability(records: list):
-    """ Normalize the probabilities for every column inbetween range(min, max) of
+    """Normalize the probabilities for every column inbetween range(min, max) of
     particulair column.
 
     Args:
